Class: CldProvisioning::Models::Shared::UpdateRolePrincipalPolicyParameters
- Inherits:
-
Object
- Object
- CldProvisioning::Models::Shared::UpdateRolePrincipalPolicyParameters
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/cld_provisioning/models/shared/updateroleprincipal_policy_parameters.rb
Overview
For roles with ‘permission_type` set to `content`, provide the ID of the specific folder or collection you want the role to apply to, for example, `“folder_id”:“asdfjkl12347890”`. This specification is passed to the `policy_statement`, written in Cedar language.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize ⇒ UpdateRolePrincipalPolicyParameters
constructor
A new instance of UpdateRolePrincipalPolicyParameters.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize ⇒ UpdateRolePrincipalPolicyParameters
Returns a new instance of UpdateRolePrincipalPolicyParameters.
15 16 |
# File 'lib/cld_provisioning/models/shared/updateroleprincipal_policy_parameters.rb', line 15 def initialize end |
Instance Method Details
#==(other) ⇒ Object
19 20 21 22 |
# File 'lib/cld_provisioning/models/shared/updateroleprincipal_policy_parameters.rb', line 19 def ==(other) return false unless other.is_a?(self.class) true end |